pub enum Date {
Ccyymmdd,
Ccyymmddhhmmzhhmm,
}Variants
Ccyymmdd
CCYYMMDD
Calendar date: C = Century ; Y = Year ; M = Month ; D = Day.
Ccyymmddhhmmzhhmm
CCYYMMDDHHMMZHHMM
Calendar date including time and time zone expressed in hours and minutes. ZHHMM = time zone given as offset from Coordinated Universal Time (UTC).