EAS

Enum EAS 

pub enum EAS {
Show 97 variants SystemInformationEtRepertoireDesEntrepriseEtDesEtablissementsSirene, Organisationsnummer, SiretCode, LyTunnus, DataUniversalNumberingSystemDUNSNumber, EanLocationCode, TheDanishBusinessAuthorityPNumberDkP, FtiEdiforumItaliaEdiraCompliant, VerenigingVanKamersVanKoophandelEnFabriekenInNederlandAssociationChambersCommerceAndIndustryInNetherlandsSchemeEdiraCompliant, DirectoratesEuropeanCommission, SiaObjectIdentifiers, SecetiObjectIdentifiers, StandardCompanyCode, AustralianBusinessNumberAbnScheme, IdentificationNumberEconomicSubjectsIco, IdentificationNumberEconomicSubjectIcoActOnStateStatistics29November200127, TeikokuCompanyCode, OdetteInternationalLimited, NuméroDidentificationSuisseDesEnterprisesIdeSwissUniqueBusinessIdentificationNumberUidb, Digstorg, CorporateNumberTheSocialSecurityAndTaxNumberSystem, DutchOriginatorsIdentificationNumber, CentreRegistersAndInformationSystemsMinistryJustice, EnhetsregisteretVedBronnoysundregisterne, UblBePartyIdentifier, KoiosOpenTechnicalDictionary, SingaporeUenIdentifier, KennitalaIcelandLegalIdForIndividualsAndLegalEntities, Erstorg, GlobalLegalEntityIdentifierGleif, LegalEntityCodeLithuania, CodiceUnivocoUnitàOrganizzativaIpa, IndirizzoDiPostaElettronicaCertificata, EdeliveryNetworkParticipantIdentifier, LeitwegId, Coddest, NumeroDentrepriseOndernemingsnummerUnternehmensnummer, Gs1IdentificationKeys, CodiceFiscale, PartitaIva, FinnishOrganizationIdentifier, FinnishOrganizationValueAddTaxIdentifier, NetServiceId, Ovtcode, TheNetherlandsChamberCommerceAndIndustryEstablishmentNumber, UnifiedRegistrationNumberLatvia, TheRegisteredNumberQualifiedInvoiceIssuer, FrctcElectronicAddress, NationalEInvoicingFramework, UaeTaxIdentificationNumberTin, RegisterLegalPersonsInFrenchRépertoireDesPersonnesMorales, HungaryVatNumber, BusinessRegistersNetwork, ÖsterreichischeUmsatzsteuerIdentifikationsnummer, ÖsterreichischesVerwaltungsBzwOrganisationskennzeichen, SocietyForWorldwideInterbankFinancialTelecommunicationSWIFT, KennzifferDesUnternehmensregisters, AgenciaEspañolaDeAdministraciónTributaria, AndorraVatNumber, AlbaniaVatNumber, BosniaAndHerzegovinaVatNumber, BelgiumVatNumber, BulgariaVatNumber, SwitzerlandVatNumber, CyprusVatNumber, CzechRepublicVatNumber, GermanyVatNumber, EstoniaVatNumber, UnitedKingdomVatNumber, GreeceVatNumber, CroatiaVatNumber, IrelandVatNumber, LiechtensteinVatNumber, LithuaniaVatNumber, LuxemburgVatNumber, LatviaVatNumber, MonacoVatNumber, MontenegroVatNumber, MacedoniaFormerYugoslavRepublicVatNumber, MaltaVatNumber, NetherlandsVatNumber, PolandVatNumber, PortugalVatNumber, RomaniaVatNumber, SerbiaVatNumber, SloveniaVatNumber, SlovakiaVatNumber, SanMarinoVatNumber, TurkeyVatNumber, HolySeeVaticanCityStateVatNumber, FrenchVatNumber, EmployerIdentificationNumberEinUsa, OFTPOdetteFileTransferProtocol, X400AddressForMailText, As2Exchange, FileTransferProtocol, ElectronicMailSmpt,
}

Variants



SystemInformationEtRepertoireDesEntrepriseEtDesEtablissementsSirene

System Information et Repertoire des Entreprise et des Etablissements: SIRENE



Organisationsnummer

Organisationsnummer



SiretCode

SIRET-CODE



LyTunnus

LY-tunnus



DataUniversalNumberingSystemDUNSNumber

Data Universal Numbering System (D-U-N-S Number)



EanLocationCode

EAN Location Code



TheDanishBusinessAuthorityPNumberDkP

The Danish Business Authority - P-number (DK:P)



FtiEdiforumItaliaEdiraCompliant

FTI - Ediforum Italia, (EDIRA compliant)



VerenigingVanKamersVanKoophandelEnFabriekenInNederlandAssociationChambersCommerceAndIndustryInNetherlandsSchemeEdiraCompliant

Vereniging van Kamers van Koophandel en Fabrieken in Nederland (Association of Chambers of Commerce and Industry in the Netherlands), Scheme (EDIRA compliant)



DirectoratesEuropeanCommission

Directorates of the European Commission



SiaObjectIdentifiers

SIA Object Identifiers



SecetiObjectIdentifiers

SECETI Object Identifiers



StandardCompanyCode

Standard Company Code



AustralianBusinessNumberAbnScheme

Australian Business Number (ABN) Scheme



IdentificationNumberEconomicSubjectsIco

Identification number of economic subjects: (ICO)



IdentificationNumberEconomicSubjectIcoActOnStateStatistics29November200127

Identification number of economic subject (ICO) Act on State Statistics of 29 November 2001,  27



TeikokuCompanyCode

Teikoku Company Code



OdetteInternationalLimited

Odette International Limited



NuméroDidentificationSuisseDesEnterprisesIdeSwissUniqueBusinessIdentificationNumberUidb

Numéro d’identification suisse des enterprises (IDE), Swiss Unique Business Identification Number (UIDB)



Digstorg

DIGSTORG



CorporateNumberTheSocialSecurityAndTaxNumberSystem

Corporate Number of The Social Security and Tax Number System



DutchOriginatorsIdentificationNumber

Dutch Originator’s Identification Number



CentreRegistersAndInformationSystemsMinistryJustice

Centre of Registers and Information Systems of the Ministry of Justice



EnhetsregisteretVedBronnoysundregisterne

Enhetsregisteret ved Bronnoysundregisterne



UblBePartyIdentifier

UBL.BE party identifier



KoiosOpenTechnicalDictionary

KOIOS Open Technical Dictionary



SingaporeUenIdentifier

Singapore UEN identifier



KennitalaIcelandLegalIdForIndividualsAndLegalEntities

Kennitala - Iceland legal id for individuals and legal entities



Erstorg

ERSTORG



GlobalLegalEntityIdentifierGleif

Global legal entity identifier (GLEIF)



LegalEntityCodeLithuania

Legal entity code (Lithuania)



CodiceUnivocoUnitàOrganizzativaIpa

Codice Univoco Unità Organizzativa iPA



IndirizzoDiPostaElettronicaCertificata

Indirizzo di Posta Elettronica Certificata



EdeliveryNetworkParticipantIdentifier

eDelivery Network Participant identifier



LeitwegId

Leitweg-ID



Coddest

CODDEST



NumeroDentrepriseOndernemingsnummerUnternehmensnummer

Numero d’entreprise / ondernemingsnummer / Unternehmensnummer



Gs1IdentificationKeys

GS1 identification keys



CodiceFiscale

CODICE FISCALE



PartitaIva

PARTITA IVA



FinnishOrganizationIdentifier

Finnish Organization Identifier



FinnishOrganizationValueAddTaxIdentifier

Finnish Organization Value Add Tax Identifier



NetServiceId

Net service ID



Ovtcode

OVTcode



TheNetherlandsChamberCommerceAndIndustryEstablishmentNumber

The Netherlands Chamber of Commerce and Industry establishment number



UnifiedRegistrationNumberLatvia

Unified registration number (Latvia)



TheRegisteredNumberQualifiedInvoiceIssuer

The registered number of the qualified invoice issuer



FrctcElectronicAddress

FRCTC ELECTRONIC ADDRESS



NationalEInvoicingFramework

National e-Invoicing Framework



UaeTaxIdentificationNumberTin

UAE Tax Identification Number (TIN)



RegisterLegalPersonsInFrenchRépertoireDesPersonnesMorales

Register of legal persons (in French : Répertoire des personnes morales)



HungaryVatNumber

Hungary VAT number



BusinessRegistersNetwork

Business Registers Network



ÖsterreichischeUmsatzsteuerIdentifikationsnummer

Österreichische Umsatzsteuer-Identifikationsnummer



ÖsterreichischesVerwaltungsBzwOrganisationskennzeichen

Österreichisches Verwaltungs bzw. Organisationskennzeichen



SocietyForWorldwideInterbankFinancialTelecommunicationSWIFT

SOCIETY FOR WORLDWIDE INTERBANK FINANCIAL, TELECOMMUNICATION S.W.I.F.T



KennzifferDesUnternehmensregisters

Kennziffer des Unternehmensregisters



AgenciaEspañolaDeAdministraciónTributaria

Agencia Española de Administración Tributaria



AndorraVatNumber

Andorra VAT number



AlbaniaVatNumber

Albania VAT number



BosniaAndHerzegovinaVatNumber

Bosnia and Herzegovina VAT number



BelgiumVatNumber

Belgium VAT number



BulgariaVatNumber

Bulgaria VAT number



SwitzerlandVatNumber

Switzerland VAT number



CyprusVatNumber

Cyprus VAT number



CzechRepublicVatNumber

Czech Republic VAT number



GermanyVatNumber

Germany VAT number



EstoniaVatNumber

Estonia VAT number



UnitedKingdomVatNumber

United Kingdom VAT number



GreeceVatNumber

Greece VAT number



CroatiaVatNumber

Croatia VAT number



IrelandVatNumber

Ireland VAT number



LiechtensteinVatNumber

Liechtenstein VAT number



LithuaniaVatNumber

Lithuania VAT number



LuxemburgVatNumber

Luxemburg VAT number



LatviaVatNumber

Latvia VAT number



MonacoVatNumber

Monaco VAT number



MontenegroVatNumber

Montenegro VAT number



MacedoniaFormerYugoslavRepublicVatNumber

Macedonia, the former Yugoslav Republic of VAT number



MaltaVatNumber

Malta VAT number



NetherlandsVatNumber

Netherlands VAT number



PolandVatNumber

Poland VAT number



PortugalVatNumber

Portugal VAT number



RomaniaVatNumber

Romania VAT number



SerbiaVatNumber

Serbia VAT number



SloveniaVatNumber

Slovenia VAT number



SlovakiaVatNumber

Slovakia VAT number



SanMarinoVatNumber

San Marino VAT number



TurkeyVatNumber

Turkey VAT number



HolySeeVaticanCityStateVatNumber

Holy See (Vatican City State) VAT number



FrenchVatNumber

French VAT number



EmployerIdentificationNumberEinUsa

Employer Identification Number (EIN, USA)



OFTPOdetteFileTransferProtocol

O.F.T.P. (ODETTE File Transfer Protocol)



X400AddressForMailText

X.400 address for mail text



As2Exchange

AS2 exchange



FileTransferProtocol

File Transfer Protocol



ElectronicMailSmpt

Electronic mail (SMPT)