ICD

Enum ICD 

pub enum ICD {
Show 239 variants SystemInformationEtRepertoireDesEntrepriseEtDesEtablissementsSirene, CodificationNumeriqueDesEtablissmentsFinanciersEnBelgique, NbsOsiNetwork, UsaFedGovOsiNetwork, UsaDodOsiNetwork, Organisationsnummer, LeNumeroNational, SiretCode, OrganizationalIdentifiersForStructuredNamesUnderIso9541Part2, InternationalCodeDesignatorForIdentificationOsiBasedAmateurRadioOrganizationsNetworkObjectsAndApplicationServices, EuropeanComputerManufacturersAssociationEcma, VsaFtpCodeFtpFileTransferProtocol, NistOsiImplememtsWorkshop, ElectronicDataInterchangeEdi, EwosObjectIdentifiers, CommonLanguage, SnaOsiNetwork, AirTransportIndustryServicesCommunicationsNetwork, EuropeanLaboratoryForParticlePhysicsCern, SocietyForWorldwideInterbankFinancialTelecommunicationSWIFT, OsfDistributedComputingObjectIdentification, NordicUniversityAndResearchNetworkNordunet, DigitalEquipmentCorporationDec, OsiAsiaOceaniaWorkshop, NatoIso6523IcdeCodingScheme, AeronauticalTelecommunicationsNetworkAtn, InternationalStandardIso6523, TheAllUnionClassifierEnterprisesAndOrganisations, AtTOsiNetwork, EdiPartnerIdentificationCode, TelecomAustralia, SGWOsiInternetwork, ReuterOpenAddressStandard, Iso6523Icd, TeletrustObjectIdentifiers, LyTunnus, TheAustralianGosipNetwork, TheOzDodOsiNetwork, UnileverGroupCompanies, CiticorpGlobalInformationNetwork, DbpTelekomObjectIdentifiers, Hydronett, ThaiIndustrialStandardsInstituteTisi, IciCompanyIdentificationSystem, Funloc, BullOdiDsaUnixNetwork, Osinz, AucklandAreaHealth, Firmenich, AgfaDis, SocietyMotionPictureAndTelevisionEngineersSmpte, Migros_networkM_netopz, Iso6523Icdpcr, EnergyNet, NokiaObjectIdentifiersNoi, SaintGobain, SiemensCorporateNetwork, Danznet, DataUniversalNumberingSystemDUNSNumber, SoffexOsi, KpnOvn, Ascomosinet, UtcUniformeTransportCode, SolvayOsiCoding, RocheCorporateNetwork, Zellwegerosinet, IntelCorporationOsi, SitaObjectIdentifierTree, DaimlerchryslerCorporateNetwork, LegoOsiNetwork, NavistarOsiNetwork, IcdFormattedAtmAddress, Arinc, AlcanetAlcatelAlsthomCorporateNetwork, SistemaItalianoDiIdentificazioneDiOgettiGestitoDaUninfo, SistemaItalianoDiIndirizzamentoDiRetiOsiGestitoDaUninfo, MitelTerminalOrSwitchingEquipment, AtmForum, UkNationalHealthServiceSchemeEdiraCompliant, InternationalNsap, NorwegianTelecommunicationsAuthoritysNtasEdiIdentifierSchemeEdiraCompliant, AdvancedTelecommunicationsModulesLimitedCorporateNetwork, AthensChamberCommerceIndustrySchemeEdiraCompliant, SwissChambersCommerceSchemeEdiraCompliant, UnitedStatesCouncilForInternationalBusinessUscibSchemeEdiraCompliant, NationalFederationChambersCommerceIndustryBelgiumSchemeEdiraCompliant, EanLocationCode, TheAssociationBritishChambersCommerceLtdSchemeEdiraCompliant, InternetIpAddressingIso6523IcdEncoding, CiscoSysytemsOsiNetwork, RevenueCanadaBusinessNumberRegistrationEdiraCompliant, DeutscherIndustrieUndHandelstagDihtSchemeEdiraCompliant, HewlettPackardCompanyInternalAmNetwork, TheDanishBusinessAuthorityPNumberDkP, FtiEdiforumItaliaEdiraCompliant, ChamberOfCommerceTelAvivJaffaSchemeEdiraCompliant, SiemensSupervisorySystemsNetwork, Png_icdScheme, SouthAfricanCodeAllocation, Heag, BtIcdCodingSystem, PortugueseChamberCommerceAndIndustrySchemeEdiraCompliant, VerenigingVanKamersVanKoophandelEnFabriekenInNederlandAssociationChambersCommerceAndIndustryInNetherlandsSchemeEdiraCompliant, AssociationSwedishChambersCommerceAndIndustrySchemeEdiraCompliant, AustralianChambersCommerceAndIndustrySchemeEdiraCompliant, BellsouthIcdAesaAtmEndSystemAddress, BellAtlantic, ObjectIdentifiers, IsoRegisterForStandardsProducingOrganizations, Originnet, CheckPointSoftwareTechnologies, PacificBellDataCommunicationsNetwork, PssObjectIdentifiers, StentorIcdCodingSystem, AtmNetworkZn96, MciOsiNetwork, Advantis, AffableSoftwareDataInterchangeCodes, BbDataGmbh, BasfCompanyAtmNetwork, IotaIdentifiersForOrganizationsForTelecommunicationsAddressingUsingIcdSystemFormatDefinedInIsoIec8348, HenkelCorporateNetworkHNet, GteOsiNetwork, DresdnerBankCorporateNetwork, BcnrSwissClearingBankNumber, BpiSwissBusinessPartnerIdentificationCode, DirectoratesEuropeanCommission, CodeForIdentificationNationalOrganizations, CerticomObjectIdentifiers, Tc68Oid, InfonetServicesCorporation, SiaObjectIdentifiers, CableWirelessGlobalAtmEndSystemAddressPlan, GlobalAesaScheme, FranceTelecomAtmEndSystemAddressPlan, SavvisCommunicationsAesa, ToshibaOrganizationsPartnersAndSuppliersTopasCode, NatoCommercialAndGovernmentEntitySystem, SecetiObjectIdentifiers, EinesteinetAg, DodaacDepartmentDefenseActivityAddressCode, DgcpDirectionGénéraleDeLaComptabilitéPubliqueAdministrativeAccountingIdentificationScheme, DgiDirectionGénéraleDesImpotsCode, StandardCompanyCode, ItuInternationalTelecommunicationsUnionDataNetworkIdentificationCodesDnic, GlobalBusinessIdentifier, MadgeNetworksLtdIcdAtmAddressingScheme, AustralianBusinessNumberAbnScheme, EdiraSchemeIdentifierCode, ConcertGlobalNetworkServicesIcdAesa, IdentificationNumberEconomicSubjectsIco, GlobalCrossingAesaAtmEndSystemAddress, Auna, AtmInterconnectionWithDutchKpnTelecom, IdentificationNumberEconomicSubjectIcoActOnStateStatistics29November200127, ActalisObjectIdentifiers, GtinGlobalTradeItemNumber, EccmaOpenTechnicalDirectory, CenIsssObjectIdentifierScheme, UsEpaFacilityIdentifier, TelusCorporation, FieieObjectIdentifiers, SwissguideIdentifierScheme, PriorityTelecomAtmEndSystemAddressPlan, VodafoneIrelandOsiAddressing, SwissFederalBusinessIdentificationNumberCentralBusinessNamesIndexZefixIdentificationNumber, TeikokuCompanyCode, LuxembourgCpCpsCertificationPolicyAndCertificationPracticeStatementIndex, ProjectGroupListsPropertiesProlist, EciSs, Stepnexus, SiemensAg, ParadineGmbh, OdetteInternationalLimited, Route1Mobinet, PenangoObjectIdentifiers, LithuanianMilitaryPki, NuméroDidentificationSuisseDesEnterprisesIdeSwissUniqueBusinessIdentificationNumberUidb, Digstorg, PercevalObjectCode, TrustpointObjectIdentifiers, AmazonUniqueIdentificationScheme, CorporateNumberTheSocialSecurityAndTaxNumberSystem, EuropeanBusinessIdentifierEbid, OrganisatieIndentificatieNummerOin, CompanyCodeEstonia, Organisasjonsnummer, UblBePartyIdentifier, KoiosOpenTechnicalDictionary, SingaporeNationwideELnvoiceFramework, IcelandicIdentifierÍslenskKennitala, AppliaPlStandard, Erstorg, LegalEntityIdentifierLei, LegalEntityCodeLithuania, CodiceUnivocoUnitàOrganizzativaIpa, IndirizzoDiPostaElettronicaCertificata, EdeliveryNetworkParticipantIdentifier, LeitwegId, Coddest, RegistreDuCommerceEtDeLIndustrieRci, PilogOntologyCodificationIdentifierPoci, NumeroDentrepriseOndernemingsnummerUnternehmensnummer, Gs1IdentificationKeys, CodiceFiscale, PartitaIva, FinnishOrganizationIdentifier, FinnishOrganizationValueAddTaxIdentifier, TradeplaceTradepiStandard, NetServiceId, Ovtcode, TheNetherlandsChamberCommerceAndIndustryEstablishmentNumber, UnifiedRegistrationNumberLatvia, TaxpayerRegistrationCodeLatvia, TheRegisterNaturalPersonsLatvia, TheRegisteredNumberQualifiedInvoiceIssuer, MetadataRegistrySupport, EuBasedCompany, FtctcCodeRoutage, FrctcElectronicAddress, FrctcParticulier, NonEuBasedCompany, RépertoireDesEntreprisesEtDesEtablissementsRidet, TAHITITraitementAutomatiqueHiérarchiséDesInstitutionsDeTahitiEtDesÎles, NationalEInvoicingFramework, SingleTaxableCompanyFrance, NobbProductNumber, Elnummer, ToimitusosoiteId, UaeTaxIdentificationNumberTin, Toimipaikkald, CprDanishPersonCivilRegistrationNumber, PlateformeSAgrééeSÀLaFacturationÉlectroniquePpfPdp, Eaeu, RegisterLegalPersonsInFrenchRépertoireDesPersonnesMorales, NameUnknown, OpenpeppolServiceProviderIdentificationSchemeSpis, NameUnknown_Dup, TaxIdentificationTaxIdNigeria,
}

Variants



SystemInformationEtRepertoireDesEntrepriseEtDesEtablissementsSirene

System Information et Repertoire des Entreprise et des Etablissements: SIRENE



CodificationNumeriqueDesEtablissmentsFinanciersEnBelgique

Codification Numerique des Etablissments Financiers En Belgique



NbsOsiNetwork

NBS/OSI NETWORK



UsaFedGovOsiNetwork

USA FED GOV OSI NETWORK



UsaDodOsiNetwork

USA DOD OSI NETWORK



Organisationsnummer

Organisationsnummer



LeNumeroNational

LE NUMERO NATIONAL



SiretCode

SIRET-CODE



OrganizationalIdentifiersForStructuredNamesUnderIso9541Part2

Organizational Identifiers for Structured Names under ISO 9541 Part 2



InternationalCodeDesignatorForIdentificationOsiBasedAmateurRadioOrganizationsNetworkObjectsAndApplicationServices

International Code Designator for the Identification of OSI-based, Amateur Radio Organizations, Network Objects and Application Services.



EuropeanComputerManufacturersAssociationEcma

European Computer Manufacturers Association: ECMA



VsaFtpCodeFtpFileTransferProtocol

VSA FTP CODE (FTP = File Transfer Protocol)



NistOsiImplememtsWorkshop

NIST/OSI Implememts’ Workshop



ElectronicDataInterchangeEdi

Electronic Data Interchange: EDI



EwosObjectIdentifiers

EWOS Object Identifiers



CommonLanguage

COMMON LANGUAGE



SnaOsiNetwork

SNA/OSI Network



AirTransportIndustryServicesCommunicationsNetwork

Air Transport Industry Services Communications Network



EuropeanLaboratoryForParticlePhysicsCern

European Laboratory for Particle Physics: CERN



SocietyForWorldwideInterbankFinancialTelecommunicationSWIFT

SOCIETY FOR WORLDWIDE INTERBANK FINANCIAL, TELECOMMUNICATION S.W.I.F.T.



OsfDistributedComputingObjectIdentification

OSF Distributed Computing Object Identification



NordicUniversityAndResearchNetworkNordunet

Nordic University and Research Network: NORDUnet



DigitalEquipmentCorporationDec

Digital Equipment Corporation: DEC



OsiAsiaOceaniaWorkshop

OSI ASIA-OCEANIA WORKSHOP



NatoIso6523IcdeCodingScheme

NATO ISO 6523 ICDE coding scheme



AeronauticalTelecommunicationsNetworkAtn

Aeronautical Telecommunications Network (ATN)



InternationalStandardIso6523

International Standard ISO 6523



TheAllUnionClassifierEnterprisesAndOrganisations

The All-Union Classifier of Enterprises and Organisations



AtTOsiNetwork

AT&T/OSI Network



EdiPartnerIdentificationCode

EDI Partner Identification Code



TelecomAustralia

Telecom Australia



SGWOsiInternetwork

S G W OSI Internetwork



ReuterOpenAddressStandard

Reuter Open Address Standard



Iso6523Icd

ISO 6523 - ICD



TeletrustObjectIdentifiers

TeleTrust Object Identifiers



LyTunnus

LY-tunnus



TheAustralianGosipNetwork

The Australian GOSIP Network



TheOzDodOsiNetwork

The OZ DOD OSI Network



UnileverGroupCompanies

Unilever Group Companies



CiticorpGlobalInformationNetwork

Citicorp Global Information Network



DbpTelekomObjectIdentifiers

DBP Telekom Object Identifiers



Hydronett

HydroNETT



ThaiIndustrialStandardsInstituteTisi

Thai Industrial Standards Institute (TISI)



IciCompanyIdentificationSystem

ICI Company Identification System



Funloc

FUNLOC



BullOdiDsaUnixNetwork

BULL ODI/DSA/UNIX Network



Osinz

OSINZ



AucklandAreaHealth

Auckland Area Health



Firmenich

Firmenich



AgfaDis

AGFA-DIS



SocietyMotionPictureAndTelevisionEngineersSmpte

Society of Motion Picture and Television Engineers (SMPTE)



Migros_networkM_netopz

Migros_Network M_NETOPZ



Iso6523Icdpcr

ISO6523 - ICDPCR



EnergyNet

Energy Net



NokiaObjectIdentifiersNoi

Nokia Object Identifiers (NOI)



SaintGobain

Saint Gobain



SiemensCorporateNetwork

Siemens Corporate Network



Danznet

DANZNET



DataUniversalNumberingSystemDUNSNumber

Data Universal Numbering System (D-U-N-S Number)



SoffexOsi

SOFFEX OSI



KpnOvn

KPN OVN



Ascomosinet

ascomOSINet



UtcUniformeTransportCode

UTC: Uniforme Transport Code



SolvayOsiCoding

SOLVAY OSI CODING



RocheCorporateNetwork

Roche Corporate Network



Zellwegerosinet

ZellwegerOSINet



IntelCorporationOsi

Intel Corporation OSI



SitaObjectIdentifierTree

SITA Object Identifier Tree



DaimlerchryslerCorporateNetwork

DaimlerChrysler Corporate Network



LegoOsiNetwork

LEGO /OSI NETWORK



NavistarOsiNetwork

NAVISTAR/OSI Network



IcdFormattedAtmAddress

ICD Formatted ATM address



Arinc

ARINC



AlcanetAlcatelAlsthomCorporateNetwork

Alcanet/Alcatel-Alsthom Corporate Network



SistemaItalianoDiIdentificazioneDiOgettiGestitoDaUninfo

Sistema Italiano di Identificazione di ogetti gestito da UNINFO



SistemaItalianoDiIndirizzamentoDiRetiOsiGestitoDaUninfo

Sistema Italiano di Indirizzamento di Reti OSI Gestito da UNINFO



MitelTerminalOrSwitchingEquipment

Mitel terminal or switching equipment



AtmForum

ATM Forum



UkNationalHealthServiceSchemeEdiraCompliant

UK National Health Service Scheme, (EDIRA compliant)



InternationalNsap

International NSAP



NorwegianTelecommunicationsAuthoritysNtasEdiIdentifierSchemeEdiraCompliant

Norwegian Telecommunications Authority’s, NTA’S, EDI, identifier scheme (EDIRA compliant)



AdvancedTelecommunicationsModulesLimitedCorporateNetwork

Advanced Telecommunications Modules Limited, Corporate Network



AthensChamberCommerceIndustrySchemeEdiraCompliant

Athens Chamber of Commerce & Industry Scheme (EDIRA compliant)



SwissChambersCommerceSchemeEdiraCompliant

Swiss Chambers of Commerce Scheme (EDIRA) compliant



UnitedStatesCouncilForInternationalBusinessUscibSchemeEdiraCompliant

United States Council for International Business (USCIB) Scheme, (EDIRA compliant)



NationalFederationChambersCommerceIndustryBelgiumSchemeEdiraCompliant

National Federation of Chambers of Commerce & Industry of Belgium, Scheme (EDIRA compliant)



EanLocationCode

EAN Location Code



TheAssociationBritishChambersCommerceLtdSchemeEdiraCompliant

The Association of British Chambers of Commerce Ltd. Scheme, (EDIRA compliant)



InternetIpAddressingIso6523IcdEncoding

Internet IP addressing - ISO 6523 ICD encoding



CiscoSysytemsOsiNetwork

Cisco Sysytems / OSI Network



RevenueCanadaBusinessNumberRegistrationEdiraCompliant

Revenue Canada Business Number Registration (EDIRA compliant)



DeutscherIndustrieUndHandelstagDihtSchemeEdiraCompliant

DEUTSCHER INDUSTRIE- UND HANDELSTAG (DIHT) Scheme (EDIRA compliant)



HewlettPackardCompanyInternalAmNetwork

Hewlett - Packard Company Internal AM Network



TheDanishBusinessAuthorityPNumberDkP

The Danish Business Authority - P-number (DK:P)



FtiEdiforumItaliaEdiraCompliant

FTI - Ediforum Italia, (EDIRA compliant)



ChamberOfCommerceTelAvivJaffaSchemeEdiraCompliant

CHAMBER OF COMMERCE TEL AVIV-JAFFA Scheme (EDIRA compliant)



SiemensSupervisorySystemsNetwork

Siemens Supervisory Systems Network



Png_icdScheme

PNG_ICD Scheme



SouthAfricanCodeAllocation

South African Code Allocation



Heag

HEAG



BtIcdCodingSystem

BT - ICD Coding System



PortugueseChamberCommerceAndIndustrySchemeEdiraCompliant

Portuguese Chamber of Commerce and Industry Scheme (EDIRA compliant)



VerenigingVanKamersVanKoophandelEnFabriekenInNederlandAssociationChambersCommerceAndIndustryInNetherlandsSchemeEdiraCompliant

Vereniging van Kamers van Koophandel en Fabrieken in Nederland (Association of Chambers of Commerce and Industry in the Netherlands), Scheme (EDIRA compliant)



AssociationSwedishChambersCommerceAndIndustrySchemeEdiraCompliant

Association of Swedish Chambers of Commerce and Industry Scheme (EDIRA compliant)



AustralianChambersCommerceAndIndustrySchemeEdiraCompliant

Australian Chambers of Commerce and Industry Scheme (EDIRA compliant)



BellsouthIcdAesaAtmEndSystemAddress

BellSouth ICD AESA (ATM End System Address)



BellAtlantic

Bell Atlantic



ObjectIdentifiers

Object Identifiers



IsoRegisterForStandardsProducingOrganizations

ISO register for Standards producing Organizations



Originnet

OriginNet



CheckPointSoftwareTechnologies

Check Point Software Technologies



PacificBellDataCommunicationsNetwork

Pacific Bell Data Communications Network



PssObjectIdentifiers

PSS Object Identifiers



StentorIcdCodingSystem

STENTOR-ICD CODING SYSTEM



AtmNetworkZn96

ATM-Network ZN’96



MciOsiNetwork

MCI / OSI Network



Advantis

Advantis



AffableSoftwareDataInterchangeCodes

Affable Software Data Interchange Codes



BbDataGmbh

BB-DATA GmbH



BasfCompanyAtmNetwork

BASF Company ATM-Network



IotaIdentifiersForOrganizationsForTelecommunicationsAddressingUsingIcdSystemFormatDefinedInIsoIec8348

IOTA Identifiers for Organizations for Telecommunications Addressing using the ICD system format defined in ISO/IEC 8348



HenkelCorporateNetworkHNet

Henkel Corporate Network (H-Net)



GteOsiNetwork

GTE/OSI Network



DresdnerBankCorporateNetwork

Dresdner Bank Corporate Network



BcnrSwissClearingBankNumber

BCNR (Swiss Clearing Bank Number)



BpiSwissBusinessPartnerIdentificationCode

BPI (Swiss Business Partner Identification) code



DirectoratesEuropeanCommission

Directorates of the European Commission



CodeForIdentificationNationalOrganizations

Code for the Identification of National Organizations



CerticomObjectIdentifiers

Certicom Object Identifiers



Tc68Oid

TC68 OID



InfonetServicesCorporation

Infonet Services Corporation



SiaObjectIdentifiers

SIA Object Identifiers



CableWirelessGlobalAtmEndSystemAddressPlan

Cable & Wireless Global ATM End-System Address Plan



GlobalAesaScheme

Global AESA scheme



FranceTelecomAtmEndSystemAddressPlan

France Telecom ATM End System Address Plan



SavvisCommunicationsAesa

Savvis Communications AESA:.



ToshibaOrganizationsPartnersAndSuppliersTopasCode

Toshiba Organizations, Partners, And Suppliers’ (TOPAS) Code



NatoCommercialAndGovernmentEntitySystem

NATO Commercial and Government Entity system



SecetiObjectIdentifiers

SECETI Object Identifiers



EinesteinetAg

EINESTEINet AG



DodaacDepartmentDefenseActivityAddressCode

DoDAAC (Department of Defense Activity Address Code)



DgcpDirectionGénéraleDeLaComptabilitéPubliqueAdministrativeAccountingIdentificationScheme

DGCP (Direction Générale de la Comptabilité Publique)administrative accounting identification scheme



DgiDirectionGénéraleDesImpotsCode

DGI (Direction Générale des Impots) code



StandardCompanyCode

Standard Company Code



ItuInternationalTelecommunicationsUnionDataNetworkIdentificationCodesDnic

ITU (International Telecommunications Union)Data Network Identification Codes (DNIC)



GlobalBusinessIdentifier

Global Business Identifier



MadgeNetworksLtdIcdAtmAddressingScheme

Madge Networks Ltd- ICD ATM Addressing Scheme



AustralianBusinessNumberAbnScheme

Australian Business Number (ABN) Scheme



EdiraSchemeIdentifierCode

Edira Scheme Identifier Code



ConcertGlobalNetworkServicesIcdAesa

Concert Global Network Services ICD AESA



IdentificationNumberEconomicSubjectsIco

Identification number of economic subjects: (ICO)



GlobalCrossingAesaAtmEndSystemAddress

Global Crossing AESA (ATM End System Address)



Auna

AUNA



AtmInterconnectionWithDutchKpnTelecom

ATM interconnection with the Dutch KPN Telecom



IdentificationNumberEconomicSubjectIcoActOnStateStatistics29November200127

Identification number of economic subject (ICO) Act on State Statistics of 29 November 2’001,  27



ActalisObjectIdentifiers

ACTALIS Object Identifiers



GtinGlobalTradeItemNumber

GTIN - Global Trade Item Number



EccmaOpenTechnicalDirectory

ECCMA Open Technical Directory



CenIsssObjectIdentifierScheme

CEN/ISSS Object Identifier Scheme



UsEpaFacilityIdentifier

US-EPA Facility Identifier



TelusCorporation

TELUS Corporation



FieieObjectIdentifiers

FIEIE Object identifiers



SwissguideIdentifierScheme

Swissguide Identifier Scheme



PriorityTelecomAtmEndSystemAddressPlan

Priority Telecom ATM End System Address Plan



VodafoneIrelandOsiAddressing

Vodafone Ireland OSI Addressing



SwissFederalBusinessIdentificationNumberCentralBusinessNamesIndexZefixIdentificationNumber

Swiss Federal Business Identification Number. Central Business names Index (zefix) Identification Number



TeikokuCompanyCode

Teikoku Company Code



LuxembourgCpCpsCertificationPolicyAndCertificationPracticeStatementIndex

Luxembourg CP & CPS (Certification Policy and Certification Practice Statement) Index



ProjectGroupListsPropertiesProlist

Project Group “Lists of Properties” (PROLIST®)



EciSs

eCI@ss



Stepnexus

StepNexus



SiemensAg

Siemens AG



ParadineGmbh

Paradine GmbH



OdetteInternationalLimited

Odette International Limited



Route1Mobinet

Route1 MobiNET



PenangoObjectIdentifiers

Penango Object Identifiers



LithuanianMilitaryPki

Lithuanian military PKI



NuméroDidentificationSuisseDesEnterprisesIdeSwissUniqueBusinessIdentificationNumberUidb

Numéro d’identification suisse des enterprises (IDE), Swiss Unique Business Identification Number (UIDB)



Digstorg

DIGSTORG



PercevalObjectCode

Perceval Object Code



TrustpointObjectIdentifiers

TrustPoint Object Identifiers



AmazonUniqueIdentificationScheme

Amazon Unique Identification Scheme



CorporateNumberTheSocialSecurityAndTaxNumberSystem

Corporate Number of The Social Security and Tax Number System



EuropeanBusinessIdentifierEbid

European Business Identifier (EBID)



OrganisatieIndentificatieNummerOin

Organisatie Indentificatie Nummer (OIN)



CompanyCodeEstonia

Company Code (Estonia)



Organisasjonsnummer

Organisasjonsnummer



UblBePartyIdentifier

UBL.BE Party Identifier



KoiosOpenTechnicalDictionary

KOIOS Open Technical Dictionary



SingaporeNationwideELnvoiceFramework

Singapore Nationwide E-lnvoice Framework



IcelandicIdentifierÍslenskKennitala

Icelandic identifier - Íslensk kennitala



AppliaPlStandard

APPLiA Pl Standard



Erstorg

ERSTORG



LegalEntityIdentifierLei

Legal Entity Identifier (LEI)



LegalEntityCodeLithuania

Legal entity code (Lithuania)



CodiceUnivocoUnitàOrganizzativaIpa

Codice Univoco Unità Organizzativa iPA



IndirizzoDiPostaElettronicaCertificata

Indirizzo di Posta Elettronica Certificata



EdeliveryNetworkParticipantIdentifier

eDelivery Network Participant identifier



LeitwegId

Leitweg-ID



Coddest

CODDEST



RegistreDuCommerceEtDeLIndustrieRci

Registre du Commerce et de l’Industrie : RCI



PilogOntologyCodificationIdentifierPoci

PiLog Ontology Codification Identifier (POCI)



NumeroDentrepriseOndernemingsnummerUnternehmensnummer

Numero d’entreprise / ondernemingsnummer / Unternehmensnummer



Gs1IdentificationKeys

GS1 identification keys



CodiceFiscale

CODICE FISCALE



PartitaIva

PARTITA IVA



FinnishOrganizationIdentifier

Finnish Organization Identifier



FinnishOrganizationValueAddTaxIdentifier

Finnish Organization Value Add Tax Identifier



TradeplaceTradepiStandard

Tradeplace TradePI Standard



NetServiceId

Net service ID



Ovtcode

OVTcode



TheNetherlandsChamberCommerceAndIndustryEstablishmentNumber

The Netherlands Chamber of Commerce and Industry establishment number



UnifiedRegistrationNumberLatvia

Unified registration number (Latvia)



TaxpayerRegistrationCodeLatvia

Taxpayer registration code (Latvia)



TheRegisterNaturalPersonsLatvia

The Register of Natural Persons (Latvia)



TheRegisteredNumberQualifiedInvoiceIssuer

The registered number of the qualified invoice issuer



MetadataRegistrySupport

Metadata Registry Support



EuBasedCompany

EU based company



FtctcCodeRoutage

FTCTC CODE ROUTAGE



FrctcElectronicAddress

FRCTC ELECTRONIC ADDRESS



FrctcParticulier

FRCTC Particulier



NonEuBasedCompany

NON - EU based company



RépertoireDesEntreprisesEtDesEtablissementsRidet

Répertoire des Entreprises et des Etablissements (RIDET)



TAHITITraitementAutomatiqueHiérarchiséDesInstitutionsDeTahitiEtDesÎles

T.A.H.I.T.I (traitement automatique hiérarchisé des institutions de Tahiti et des îles)



NationalEInvoicingFramework

National e-Invoicing Framework



SingleTaxableCompanyFrance

Single taxable company (France)



NobbProductNumber

NOBB product number



Elnummer

Elnummer



ToimitusosoiteId

Toimitusosoite ID



UaeTaxIdentificationNumberTin

UAE Tax Identification Number (TIN)



Toimipaikkald

ToimipaikkalD



CprDanishPersonCivilRegistrationNumber

CPR (Danish person civil registration number)



PlateformeSAgrééeSÀLaFacturationÉlectroniquePpfPdp

Plateforme.s agréée.s à la facturation électronique (PPF/PDP)



Eaeu

EAEU



RegisterLegalPersonsInFrenchRépertoireDesPersonnesMorales

Register of legal persons (in French : Répertoire des personnes morales)



NameUnknown

Name unknown



OpenpeppolServiceProviderIdentificationSchemeSpis

OpenPeppol Service Provider Identification Scheme (SPIS)



NameUnknown_Dup

Name unknown



TaxIdentificationTaxIdNigeria

Tax Identification (Tax ID), Nigeria